@@ -10,12 +10,23 @@ def kfold(model, predictor,
     """
     if not isReg:
         name = {
-            'lr' : 'Logistic Regression',
+            'lr': 'Logistic Regression',
+            'sgd': 'Stochastic Gradient Descent',
+            'perc': 'Perceptron',
+            'pass': 'Passive Aggressive Classifier',
+            'ridg': 'Ridge Classifier',
+            'ridgCV': 'Ridge Classifier with Cross Validation',
             'svm': 'Support Vector Machine',
-            'knn': 'K-Nearest Neighbors',
-            'dt' : 'Decision Trees',
-            'nb' : 'Naive Bayes',
+            'knn': 'K-Nearest Neighbours',
+            'dt': 'Decision Trees',
+            'nb': 'Naive Bayes',
             'rfc': 'Random Forest Classifier',
+            'gbc': 'Gradient Boosting Classifier',
+            'ada': 'AdaBoost Classifier',
+            'bag': 'Bagging Classifier',
+            'extc': 'Extra Trees Classifier',
+            'lgbm': 'LightGBM Classifier',
+            'cat': 'CatBoost Classifier',
             'xgb': 'XGBoost Classifier',
             'ann': 'Artificial Neural Network',
         }
